@@ -3,4 +3,4 @@
 BASE_URL = "https://www.heinrich-hertz-schule-hamburg.de/"
 LOGIN_URL = BASE_URL + "OnlineVertretungsplan.php"
 LOGIN_TEXT = "angemeldet als"
-KEY_ALLE = "alle"
\ No newline at end of file
+KEY_ALLE = "_"
\ No newline at end of file
